# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/transport.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.monitoring import monitoring_pb2 as stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/transport.proto',
  package='stellarstation.api.v1',
  syntax='proto3',
  serialized_options=b'\n\031com.stellarstation.api.v1B\016TransportProtoP\001Z2github.com/infostellarinc/go-stellarstation/api/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%stellarstation/api/v1/transport.proto\x12\x15stellarstation.api.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31stellarstation/api/v1/monitoring/monitoring.proto\"\xfa\x01\n\tTelemetry\x12/\n\x07\x66raming\x18\x01 \x01(\x0e\x32\x1e.stellarstation.api.v1.Framing\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x1d\n\x15\x64ownlink_frequency_hz\x18\x03 \x01(\x04\x12<\n\x18time_first_byte_received\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17time_last_byte_received\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rame_header\x18\x06 \x01(\x0c\"\x9f\x02\n\x0bStreamEvent\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12W\n\x0c\x63ommand_sent\x18\x02 \x01(\x0b\x32?.stellarstation.api.v1.StreamEvent.CommandSentFromGroundStationH\x00\x12K\n\x15plan_monitoring_event\x18\x03 \x01(\x0b\x32*.stellarstation.api.v1.PlanMonitoringEventH\x00\x1a\x1e\n\x1c\x43ommandSentFromGroundStationB\x07\n\x05\x45vent\"\xd8\x02\n\x13PlanMonitoringEvent\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63hannel_set_id\x18\x05 \x01(\t\x12\x64\n\x1cground_station_configuration\x18\x02 \x01(\x0b\x32<.stellarstation.api.v1.monitoring.GroundStationConfigurationH\x00\x12T\n\x14ground_station_state\x18\x03 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.GroundStationStateH\x00\x12T\n\x14ground_station_event\x18\x04 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.GroundStationEventH\x00\x42\x06\n\x04Info*l\n\x07\x46raming\x12\r\n\tBITSTREAM\x10\x00\x12\x08\n\x04\x41X25\x10\x01\x12\x06\n\x02IQ\x10\x02\x12\r\n\tIMAGE_PNG\x10\x03\x12\x0e\n\nIMAGE_JPEG\x10\x04\x12\x12\n\x0e\x46REE_TEXT_UTF8\x10\x05\x12\r\n\tWATERFALL\x10\x06\x42\x61\n\x19\x63om.stellarstation.api.v1B\x0eTransportProtoP\x01Z2github.com/infostellarinc/go-stellarstation/api/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2.DESCRIPTOR,])

_FRAMING = _descriptor.EnumDescriptor(
  name='Framing',
  full_name='stellarstation.api.v1.Framing',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BITSTREAM', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AX25', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IQ', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_PNG', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_JPEG', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FREE_TEXT_UTF8', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WATERFALL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1038,
  serialized_end=1146,
)
_sym_db.RegisterEnumDescriptor(_FRAMING)

Framing = enum_type_wrapper.EnumTypeWrapper(_FRAMING)
BITSTREAM = 0
AX25 = 1
IQ = 2
IMAGE_PNG = 3
IMAGE_JPEG = 4
FREE_TEXT_UTF8 = 5
WATERFALL = 6



_TELEMETRY = _descriptor.Descriptor(
  name='Telemetry',
  full_name='stellarstation.api.v1.Telemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='framing', full_name='stellarstation.api.v1.Telemetry.framing', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='stellarstation.api.v1.Telemetry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downlink_frequency_hz', full_name='stellarstation.api.v1.Telemetry.downlink_frequency_hz', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_first_byte_received', full_name='stellarstation.api.v1.Telemetry.time_first_byte_received', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_byte_received', full_name='stellarstation.api.v1.Telemetry.time_last_byte_received', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_header', full_name='stellarstation.api.v1.Telemetry.frame_header', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=399,
)


_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION = _descriptor.Descriptor(
  name='CommandSentFromGroundStation',
  full_name='stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=680,
)

_STREAMEVENT = _descriptor.Descriptor(
  name='StreamEvent',
  full_name='stellarstation.api.v1.StreamEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='stellarstation.api.v1.StreamEvent.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='stellarstation.api.v1.StreamEvent.timestamp', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_sent', full_name='stellarstation.api.v1.StreamEvent.command_sent', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_monitoring_event', full_name='stellarstation.api.v1.StreamEvent.plan_monitoring_event', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Event', full_name='stellarstation.api.v1.StreamEvent.Event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=402,
  serialized_end=689,
)


_PLANMONITORINGEVENT = _descriptor.Descriptor(
  name='PlanMonitoringEvent',
  full_name='stellarstation.api.v1.PlanMonitoringEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.PlanMonitoringEvent.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_set_id', full_name='stellarstation.api.v1.PlanMonitoringEvent.channel_set_id', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_configuration', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_configuration', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_state', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_state', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_event', full_name='stellarstation.api.v1.PlanMonitoringEvent.ground_station_event', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Info', full_name='stellarstation.api.v1.PlanMonitoringEvent.Info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=692,
  serialized_end=1036,
)

_TELEMETRY.fields_by_name['framing'].enum_type = _FRAMING
_TELEMETRY.fields_by_name['time_first_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TELEMETRY.fields_by_name['time_last_byte_received'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENT_COMMANDSENTFROMGROUNDSTATION.containing_type = _STREAMEVENT
_STREAMEVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEVENT.fields_by_name['command_sent'].message_type = _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION
_STREAMEVENT.fields_by_name['plan_monitoring_event'].message_type = _PLANMONITORINGEVENT
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['command_sent'])
_STREAMEVENT.fields_by_name['command_sent'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_STREAMEVENT.oneofs_by_name['Event'].fields.append(
  _STREAMEVENT.fields_by_name['plan_monitoring_event'])
_STREAMEVENT.fields_by_name['plan_monitoring_event'].containing_oneof = _STREAMEVENT.oneofs_by_name['Event']
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONCONFIGURATION
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONSTATE
_PLANMONITORINGEVENT.fields_by_name['ground_station_event'].message_type = stellarstation_dot_api_dot_v1_dot_monitoring_dot_monitoring__pb2._GROUNDSTATIONEVENT
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_configuration'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_state'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_state'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
_PLANMONITORINGEVENT.oneofs_by_name['Info'].fields.append(
  _PLANMONITORINGEVENT.fields_by_name['ground_station_event'])
_PLANMONITORINGEVENT.fields_by_name['ground_station_event'].containing_oneof = _PLANMONITORINGEVENT.oneofs_by_name['Info']
DESCRIPTOR.message_types_by_name['Telemetry'] = _TELEMETRY
DESCRIPTOR.message_types_by_name['StreamEvent'] = _STREAMEVENT
DESCRIPTOR.message_types_by_name['PlanMonitoringEvent'] = _PLANMONITORINGEVENT
DESCRIPTOR.enum_types_by_name['Framing'] = _FRAMING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Telemetry = _reflection.GeneratedProtocolMessageType('Telemetry', (_message.Message,), {
  'DESCRIPTOR' : _TELEMETRY,
  '__module__' : 'stellarstation.api.v1.transport_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Telemetry)
  })
_sym_db.RegisterMessage(Telemetry)

StreamEvent = _reflection.GeneratedProtocolMessageType('StreamEvent', (_message.Message,), {

  'CommandSentFromGroundStation' : _reflection.GeneratedProtocolMessageType('CommandSentFromGroundStation', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEVENT_COMMANDSENTFROMGROUNDSTATION,
    '__module__' : 'stellarstation.api.v1.transport_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent.CommandSentFromGroundStation)
    })
  ,
  'DESCRIPTOR' : _STREAMEVENT,
  '__module__' : 'stellarstation.api.v1.transport_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.StreamEvent)
  })
_sym_db.RegisterMessage(StreamEvent)
_sym_db.RegisterMessage(StreamEvent.CommandSentFromGroundStation)

PlanMonitoringEvent = _reflection.GeneratedProtocolMessageType('PlanMonitoringEvent', (_message.Message,), {
  'DESCRIPTOR' : _PLANMONITORINGEVENT,
  '__module__' : 'stellarstation.api.v1.transport_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.PlanMonitoringEvent)
  })
_sym_db.RegisterMessage(PlanMonitoringEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/groundstation/groundstation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.common import common_pb2 as stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2
from stellarstation.api.v1.radio import radio_pb2 as stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2
from stellarstation.api.v1 import stellarstation_pb2 as stellarstation_dot_api_dot_v1_dot_stellarstation__pb2
from stellarstation.api.v1 import transport_pb2 as stellarstation_dot_api_dot_v1_dot_transport__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/groundstation/groundstation.proto',
  package='stellarstation.api.v1.groundstation',
  syntax='proto3',
  serialized_options=b'\n\'com.stellarstation.api.v1.groundstationB\022GroundStationProtoP\001Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstation',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7stellarstation/api/v1/groundstation/groundstation.proto\x12#stellarstation.api.v1.groundstation\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)stellarstation/api/v1/common/common.proto\x1a\'stellarstation/api/v1/radio/radio.proto\x1a*stellarstation/api/v1/stellarstation.proto\x1a%stellarstation/api/v1/transport.proto\"$\n\x11\x43\x61ncelPlanRequest\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\"\x14\n\x12\x43\x61ncelPlanResponse\"\x8c\x01\n\x10ListPlansRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"L\n\x11ListPlansResponse\x12\x37\n\x04plan\x18\x01 \x03(\x0b\x32).stellarstation.api.v1.groundstation.Plan\"\x9d\x06\n\x04Plan\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x35\n\x03tle\x18\x02 \x01(\x0b\x32(.stellarstation.api.v1.groundstation.Tle\x12.\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x61os_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\x15\x64ownlink_radio_device\x18\x05 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\x12R\n\x13uplink_radio_device\x18\x06 \x01(\x0b\x32\x35.stellarstation.api.v1.radio.RadioDeviceConfiguration\x12X\n\x15satellite_coordinates\x18\t \x03(\x0b\x32\x39.stellarstation.api.v1.groundstation.SatelliteCoordinates\x12#\n\x1bsatellite_organization_name\x18\n \x01(\t\x12(\n ground_station_organization_name\x18\x0b \x01(\t\x12\x19\n\x11ground_station_id\x18\r \x01(\t\x12\x12\n\nunit_price\x18\x0c \x01(\x01\x12\x14\n\x0csatellite_id\x18\x0e \x01(\t\x12\x36\n\x0b\x63hannel_set\x18\x0f \x01(\x0b\x32!.stellarstation.api.v1.ChannelSet\x12\x43\n\x08metadata\x18\x10 \x01(\x0b\x32\x31.stellarstation.api.v1.groundstation.PlanMetadata\"\xe8\x01\n\x0cPlanMetadata\x12Q\n\x08metadata\x18\x02 \x03(\x0b\x32?.stellarstation.api.v1.groundstation.PlanMetadata.MetadataEntry\x1a\x18\n\x08Metadata\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\x1ak\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.stellarstation.api.v1.groundstation.PlanMetadata.Metadata:\x02\x38\x01\"%\n\x03Tle\x12\x0e\n\x06line_1\x18\x01 \x01(\t\x12\x0e\n\x06line_2\x18\x02 \x01(\t\"\x88\x01\n\x14SatelliteCoordinates\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x05\x61ngle\x18\x02 \x01(\x0b\x32#.stellarstation.api.v1.common.Angle\x12\x12\n\nrange_rate\x18\x03 \x01(\x01\"\x87\x01\n\x14UnavailabilityWindow\x12\x11\n\twindow_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9b\x01\n ListUnavailabilityWindowsRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n!ListUnavailabilityWindowsResponse\x12I\n\x06window\x18\x01 \x03(\x0b\x32\x39.stellarstation.api.v1.groundstation.UnavailabilityWindow\"\x99\x01\n\x1e\x41\x64\x64UnavailabilityWindowRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"4\n\x1f\x41\x64\x64UnavailabilityWindowResponse\x12\x11\n\twindow_id\x18\x01 \x01(\t\"6\n!DeleteUnavailabilityWindowRequest\x12\x11\n\twindow_id\x18\x01 \x01(\t\"$\n\"DeleteUnavailabilityWindowResponse\"\xea\x01\n\x1aGroundStationStreamRequest\x12\x19\n\x11ground_station_id\x18\x01 \x01(\t\x12\x12\n\nstream_tag\x18\x02 \x01(\t\x12V\n\x13satellite_telemetry\x18\x03 \x01(\x0b\x32\x37.stellarstation.api.v1.groundstation.SatelliteTelemetryH\x00\x12:\n\x0cstream_event\x18\x04 \x01(\x0b\x32\".stellarstation.api.v1.StreamEventH\x00\x42\t\n\x07Request\"r\n\x12SatelliteTelemetry\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63hannel_set_id\x18\x03 \x01(\t\x12\x33\n\ttelemetry\x18\x02 \x01(\x0b\x32 .stellarstation.api.v1.Telemetry\"\x8f\x02\n\x1bGroundStationStreamResponse\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x13\n\x0bresponse_id\x18\x02 \x01(\t\x12T\n\x12satellite_commands\x18\x03 \x01(\x0b\x32\x36.stellarstation.api.v1.groundstation.SatelliteCommandsH\x00\x12h\n$ground_station_configuration_request\x18\x04 \x01(\x0b\x32\x38.stellarstation.api.v1.GroundStationConfigurationRequestH\x00\x42\n\n\x08Response\"$\n\x11SatelliteCommands\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\x0c\"\x17\n\x15GetCurrentPlanRequest\"Q\n\x16GetCurrentPlanResponse\x12\x37\n\x04plan\x18\x01 \x01(\x0b\x32).stellarstation.api.v1.groundstation.Plan2\xc4\x08\n\x14GroundStationService\x12\xa4\x01\n\x17\x41\x64\x64UnavailabilityWindow\x12\x43.stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest\x1a\x44.stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse\x12}\n\nCancelPlan\x12\x36.stellarstation.api.v1.groundstation.CancelPlanRequest\x1a\x37.stellarstation.api.v1.groundstation.CancelPlanResponse\x12\xad\x01\n\x1a\x44\x65leteUnavailabilityWindow\x12\x46.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest\x1aG.stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse\x12z\n\tListPlans\x12\x35.stellarstation.api.v1.groundstation.ListPlansRequest\x1a\x36.stellarstation.api.v1.groundstation.ListPlansResponse\x12\xaa\x01\n\x19ListUnavailabilityWindows\x12\x45.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest\x1a\x46.stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse\x12\xa0\x01\n\x17OpenGroundStationStream\x12?.stellarstation.api.v1.groundstation.GroundStationStreamRequest\x1a@.stellarstation.api.v1.groundstation.GroundStationStreamResponse(\x01\x30\x01\x12\x89\x01\n\x0eGetCurrentPlan\x12:.stellarstation.api.v1.groundstation.GetCurrentPlanRequest\x1a;.stellarstation.api.v1.groundstation.GetCurrentPlanResponseB\x81\x01\n\'com.stellarstation.api.v1.groundstationB\x12GroundStationProtoP\x01Z@github.com/infostellarinc/go-stellarstation/api/v1/groundstationb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_transport__pb2.DESCRIPTOR,])




_CANCELPLANREQUEST = _descriptor.Descriptor(
  name='CancelPlanRequest',
  full_name='stellarstation.api.v1.groundstation.CancelPlanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.CancelPlanRequest.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=332,
)


_CANCELPLANRESPONSE = _descriptor.Descriptor(
  name='CancelPlanResponse',
  full_name='stellarstation.api.v1.groundstation.CancelPlanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=354,
)


_LISTPLANSREQUEST = _descriptor.Descriptor(
  name='ListPlansRequest',
  full_name='stellarstation.api.v1.groundstation.ListPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.groundstation.ListPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=497,
)


_LISTPLANSRESPONSE = _descriptor.Descriptor(
  name='ListPlansResponse',
  full_name='stellarstation.api.v1.groundstation.ListPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.groundstation.ListPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=575,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.groundstation.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.Plan.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.groundstation.Plan.tle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.Plan.start_time', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.Plan.end_time', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.groundstation.Plan.aos_time', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.groundstation.Plan.los_time', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downlink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.downlink_radio_device', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uplink_radio_device', full_name='stellarstation.api.v1.groundstation.Plan.uplink_radio_device', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_coordinates', full_name='stellarstation.api.v1.groundstation.Plan.satellite_coordinates', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_organization_name', full_name='stellarstation.api.v1.groundstation.Plan.satellite_organization_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_organization_name', full_name='stellarstation.api.v1.groundstation.Plan.ground_station_organization_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.Plan.ground_station_id', index=11,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_price', full_name='stellarstation.api.v1.groundstation.Plan.unit_price', index=12,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.groundstation.Plan.satellite_id', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_set', full_name='stellarstation.api.v1.groundstation.Plan.channel_set', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='stellarstation.api.v1.groundstation.Plan.metadata', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=1375,
)


_PLANMETADATA_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='stellarstation.api.v1.groundstation.PlanMetadata.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='stellarstation.api.v1.groundstation.PlanMetadata.Metadata.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1477,
  serialized_end=1501,
)

_PLANMETADATA_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='stellarstation.api.v1.groundstation.PlanMetadata.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='stellarstation.api.v1.groundstation.PlanMetadata.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='stellarstation.api.v1.groundstation.PlanMetadata.MetadataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1610,
)

_PLANMETADATA = _descriptor.Descriptor(
  name='PlanMetadata',
  full_name='stellarstation.api.v1.groundstation.PlanMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='stellarstation.api.v1.groundstation.PlanMetadata.metadata', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PLANMETADATA_METADATA, _PLANMETADATA_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1378,
  serialized_end=1610,
)


_TLE = _descriptor.Descriptor(
  name='Tle',
  full_name='stellarstation.api.v1.groundstation.Tle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_1', full_name='stellarstation.api.v1.groundstation.Tle.line_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_2', full_name='stellarstation.api.v1.groundstation.Tle.line_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1649,
)


_SATELLITECOORDINATES = _descriptor.Descriptor(
  name='SatelliteCoordinates',
  full_name='stellarstation.api.v1.groundstation.SatelliteCoordinates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='stellarstation.api.v1.groundstation.SatelliteCoordinates.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angle', full_name='stellarstation.api.v1.groundstation.SatelliteCoordinates.angle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range_rate', full_name='stellarstation.api.v1.groundstation.SatelliteCoordinates.range_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1652,
  serialized_end=1788,
)


_UNAVAILABILITYWINDOW = _descriptor.Descriptor(
  name='UnavailabilityWindow',
  full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.UnavailabilityWindow.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1791,
  serialized_end=1926,
)


_LISTUNAVAILABILITYWINDOWSREQUEST = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsRequest',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1929,
  serialized_end=2084,
)


_LISTUNAVAILABILITYWINDOWSRESPONSE = _descriptor.Descriptor(
  name='ListUnavailabilityWindowsResponse',
  full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='window', full_name='stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse.window', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2196,
)


_ADDUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='AddUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2199,
  serialized_end=2352,
)


_ADDUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='AddUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2354,
  serialized_end=2406,
)


_DELETEUNAVAILABILITYWINDOWREQUEST = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowRequest',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='window_id', full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest.window_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2408,
  serialized_end=2462,
)


_DELETEUNAVAILABILITYWINDOWRESPONSE = _descriptor.Descriptor(
  name='DeleteUnavailabilityWindowResponse',
  full_name='stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2464,
  serialized_end=2500,
)


_GROUNDSTATIONSTREAMREQUEST = _descriptor.Descriptor(
  name='GroundStationStreamRequest',
  full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ground_station_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.ground_station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_tag', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.stream_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_telemetry', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.satellite_telemetry', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_event', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.stream_event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Request', full_name='stellarstation.api.v1.groundstation.GroundStationStreamRequest.Request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2503,
  serialized_end=2737,
)


_SATELLITETELEMETRY = _descriptor.Descriptor(
  name='SatelliteTelemetry',
  full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_set_id', full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry.channel_set_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='stellarstation.api.v1.groundstation.SatelliteTelemetry.telemetry', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2739,
  serialized_end=2853,
)


_GROUNDSTATIONSTREAMRESPONSE = _descriptor.Descriptor(
  name='GroundStationStreamResponse',
  full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_id', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.response_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_commands', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.satellite_commands', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ground_station_configuration_request', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.ground_station_configuration_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Response', full_name='stellarstation.api.v1.groundstation.GroundStationStreamResponse.Response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2856,
  serialized_end=3127,
)


_SATELLITECOMMANDS = _descriptor.Descriptor(
  name='SatelliteCommands',
  full_name='stellarstation.api.v1.groundstation.SatelliteCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.groundstation.SatelliteCommands.command', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3129,
  serialized_end=3165,
)


_GETCURRENTPLANREQUEST = _descriptor.Descriptor(
  name='GetCurrentPlanRequest',
  full_name='stellarstation.api.v1.groundstation.GetCurrentPlanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3167,
  serialized_end=3190,
)


_GETCURRENTPLANRESPONSE = _descriptor.Descriptor(
  name='GetCurrentPlanResponse',
  full_name='stellarstation.api.v1.groundstation.GetCurrentPlanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.groundstation.GetCurrentPlanResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3192,
  serialized_end=3273,
)

_LISTPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_PLAN.fields_by_name['tle'].message_type = _TLE
_PLAN.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['downlink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_PLAN.fields_by_name['uplink_radio_device'].message_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._RADIODEVICECONFIGURATION
_PLAN.fields_by_name['satellite_coordinates'].message_type = _SATELLITECOORDINATES
_PLAN.fields_by_name['channel_set'].message_type = stellarstation_dot_api_dot_v1_dot_stellarstation__pb2._CHANNELSET
_PLAN.fields_by_name['metadata'].message_type = _PLANMETADATA
_PLANMETADATA_METADATA.containing_type = _PLANMETADATA
_PLANMETADATA_METADATAENTRY.fields_by_name['value'].message_type = _PLANMETADATA_METADATA
_PLANMETADATA_METADATAENTRY.containing_type = _PLANMETADATA
_PLANMETADATA.fields_by_name['metadata'].message_type = _PLANMETADATA_METADATAENTRY
_SATELLITECOORDINATES.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SATELLITECOORDINATES.fields_by_name['angle'].message_type = stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2._ANGLE
_UNAVAILABILITYWINDOW.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UNAVAILABILITYWINDOW.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTUNAVAILABILITYWINDOWSRESPONSE.fields_by_name['window'].message_type = _UNAVAILABILITYWINDOW
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ADDUNAVAILABILITYWINDOWREQUEST.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'].message_type = _SATELLITETELEMETRY
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._STREAMEVENT
_GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'])
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['satellite_telemetry'].containing_oneof = _GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request']
_GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'])
_GROUNDSTATIONSTREAMREQUEST.fields_by_name['stream_event'].containing_oneof = _GROUNDSTATIONSTREAMREQUEST.oneofs_by_name['Request']
_SATELLITETELEMETRY.fields_by_name['telemetry'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._TELEMETRY
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'].message_type = _SATELLITECOMMANDS
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['ground_station_configuration_request'].message_type = stellarstation_dot_api_dot_v1_dot_stellarstation__pb2._GROUNDSTATIONCONFIGURATIONREQUEST
_GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'])
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['satellite_commands'].containing_oneof = _GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response']
_GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _GROUNDSTATIONSTREAMRESPONSE.fields_by_name['ground_station_configuration_request'])
_GROUNDSTATIONSTREAMRESPONSE.fields_by_name['ground_station_configuration_request'].containing_oneof = _GROUNDSTATIONSTREAMRESPONSE.oneofs_by_name['Response']
_GETCURRENTPLANRESPONSE.fields_by_name['plan'].message_type = _PLAN
DESCRIPTOR.message_types_by_name['CancelPlanRequest'] = _CANCELPLANREQUEST
DESCRIPTOR.message_types_by_name['CancelPlanResponse'] = _CANCELPLANRESPONSE
DESCRIPTOR.message_types_by_name['ListPlansRequest'] = _LISTPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListPlansResponse'] = _LISTPLANSRESPONSE
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['PlanMetadata'] = _PLANMETADATA
DESCRIPTOR.message_types_by_name['Tle'] = _TLE
DESCRIPTOR.message_types_by_name['SatelliteCoordinates'] = _SATELLITECOORDINATES
DESCRIPTOR.message_types_by_name['UnavailabilityWindow'] = _UNAVAILABILITYWINDOW
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsRequest'] = _LISTUNAVAILABILITYWINDOWSREQUEST
DESCRIPTOR.message_types_by_name['ListUnavailabilityWindowsResponse'] = _LISTUNAVAILABILITYWINDOWSRESPONSE
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowRequest'] = _ADDUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['AddUnavailabilityWindowResponse'] = _ADDUNAVAILABILITYWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowRequest'] = _DELETEUNAVAILABILITYWINDOWREQUEST
DESCRIPTOR.message_types_by_name['DeleteUnavailabilityWindowResponse'] = _DELETEUNAVAILABILITYWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['GroundStationStreamRequest'] = _GROUNDSTATIONSTREAMREQUEST
DESCRIPTOR.message_types_by_name['SatelliteTelemetry'] = _SATELLITETELEMETRY
DESCRIPTOR.message_types_by_name['GroundStationStreamResponse'] = _GROUNDSTATIONSTREAMRESPONSE
DESCRIPTOR.message_types_by_name['SatelliteCommands'] = _SATELLITECOMMANDS
DESCRIPTOR.message_types_by_name['GetCurrentPlanRequest'] = _GETCURRENTPLANREQUEST
DESCRIPTOR.message_types_by_name['GetCurrentPlanResponse'] = _GETCURRENTPLANRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CancelPlanRequest = _reflection.GeneratedProtocolMessageType('CancelPlanRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPLANREQUEST,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.CancelPlanRequest)
  })
_sym_db.RegisterMessage(CancelPlanRequest)

CancelPlanResponse = _reflection.GeneratedProtocolMessageType('CancelPlanResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPLANRESPONSE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.CancelPlanResponse)
  })
_sym_db.RegisterMessage(CancelPlanResponse)

ListPlansRequest = _reflection.GeneratedProtocolMessageType('ListPlansRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLANSREQUEST,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansRequest)
  })
_sym_db.RegisterMessage(ListPlansRequest)

ListPlansResponse = _reflection.GeneratedProtocolMessageType('ListPlansResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLANSRESPONSE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListPlansResponse)
  })
_sym_db.RegisterMessage(ListPlansResponse)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), {
  'DESCRIPTOR' : _PLAN,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Plan)
  })
_sym_db.RegisterMessage(Plan)

PlanMetadata = _reflection.GeneratedProtocolMessageType('PlanMetadata', (_message.Message,), {

  'Metadata' : _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
    'DESCRIPTOR' : _PLANMETADATA_METADATA,
    '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.PlanMetadata.Metadata)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLANMETADATA_METADATAENTRY,
    '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.PlanMetadata.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _PLANMETADATA,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.PlanMetadata)
  })
_sym_db.RegisterMessage(PlanMetadata)
_sym_db.RegisterMessage(PlanMetadata.Metadata)
_sym_db.RegisterMessage(PlanMetadata.MetadataEntry)

Tle = _reflection.GeneratedProtocolMessageType('Tle', (_message.Message,), {
  'DESCRIPTOR' : _TLE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.Tle)
  })
_sym_db.RegisterMessage(Tle)

SatelliteCoordinates = _reflection.GeneratedProtocolMessageType('SatelliteCoordinates', (_message.Message,), {
  'DESCRIPTOR' : _SATELLITECOORDINATES,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.SatelliteCoordinates)
  })
_sym_db.RegisterMessage(SatelliteCoordinates)

UnavailabilityWindow = _reflection.GeneratedProtocolMessageType('UnavailabilityWindow', (_message.Message,), {
  'DESCRIPTOR' : _UNAVAILABILITYWINDOW,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.UnavailabilityWindow)
  })
_sym_db.RegisterMessage(UnavailabilityWindow)

ListUnavailabilityWindowsRequest = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUNAVAILABILITYWINDOWSREQUEST,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsRequest)
  })
_sym_db.RegisterMessage(ListUnavailabilityWindowsRequest)

ListUnavailabilityWindowsResponse = _reflection.GeneratedProtocolMessageType('ListUnavailabilityWindowsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUNAVAILABILITYWINDOWSRESPONSE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.ListUnavailabilityWindowsResponse)
  })
_sym_db.RegisterMessage(ListUnavailabilityWindowsResponse)

AddUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDUNAVAILABILITYWINDOWREQUEST,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowRequest)
  })
_sym_db.RegisterMessage(AddUnavailabilityWindowRequest)

AddUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('AddUnavailabilityWindowResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDUNAVAILABILITYWINDOWRESPONSE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.AddUnavailabilityWindowResponse)
  })
_sym_db.RegisterMessage(AddUnavailabilityWindowResponse)

DeleteUnavailabilityWindowRequest = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUNAVAILABILITYWINDOWREQUEST,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowRequest)
  })
_sym_db.RegisterMessage(DeleteUnavailabilityWindowRequest)

DeleteUnavailabilityWindowResponse = _reflection.GeneratedProtocolMessageType('DeleteUnavailabilityWindowResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUNAVAILABILITYWINDOWRESPONSE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.DeleteUnavailabilityWindowResponse)
  })
_sym_db.RegisterMessage(DeleteUnavailabilityWindowResponse)

GroundStationStreamRequest = _reflection.GeneratedProtocolMessageType('GroundStationStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUNDSTATIONSTREAMREQUEST,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GroundStationStreamRequest)
  })
_sym_db.RegisterMessage(GroundStationStreamRequest)

SatelliteTelemetry = _reflection.GeneratedProtocolMessageType('SatelliteTelemetry', (_message.Message,), {
  'DESCRIPTOR' : _SATELLITETELEMETRY,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.SatelliteTelemetry)
  })
_sym_db.RegisterMessage(SatelliteTelemetry)

GroundStationStreamResponse = _reflection.GeneratedProtocolMessageType('GroundStationStreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUNDSTATIONSTREAMRESPONSE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GroundStationStreamResponse)
  })
_sym_db.RegisterMessage(GroundStationStreamResponse)

SatelliteCommands = _reflection.GeneratedProtocolMessageType('SatelliteCommands', (_message.Message,), {
  'DESCRIPTOR' : _SATELLITECOMMANDS,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.SatelliteCommands)
  })
_sym_db.RegisterMessage(SatelliteCommands)

GetCurrentPlanRequest = _reflection.GeneratedProtocolMessageType('GetCurrentPlanRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTPLANREQUEST,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GetCurrentPlanRequest)
  })
_sym_db.RegisterMessage(GetCurrentPlanRequest)

GetCurrentPlanResponse = _reflection.GeneratedProtocolMessageType('GetCurrentPlanResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTPLANRESPONSE,
  '__module__' : 'stellarstation.api.v1.groundstation.groundstation_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.groundstation.GetCurrentPlanResponse)
  })
_sym_db.RegisterMessage(GetCurrentPlanResponse)


DESCRIPTOR._options = None
_PLANMETADATA_METADATAENTRY._options = None

_GROUNDSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='GroundStationService',
  full_name='stellarstation.api.v1.groundstation.GroundStationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3276,
  serialized_end=4368,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.AddUnavailabilityWindow',
    index=0,
    containing_service=None,
    input_type=_ADDUNAVAILABILITYWINDOWREQUEST,
    output_type=_ADDUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelPlan',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.CancelPlan',
    index=1,
    containing_service=None,
    input_type=_CANCELPLANREQUEST,
    output_type=_CANCELPLANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUnavailabilityWindow',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.DeleteUnavailabilityWindow',
    index=2,
    containing_service=None,
    input_type=_DELETEUNAVAILABILITYWINDOWREQUEST,
    output_type=_DELETEUNAVAILABILITYWINDOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPlans',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListPlans',
    index=3,
    containing_service=None,
    input_type=_LISTPLANSREQUEST,
    output_type=_LISTPLANSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUnavailabilityWindows',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.ListUnavailabilityWindows',
    index=4,
    containing_service=None,
    input_type=_LISTUNAVAILABILITYWINDOWSREQUEST,
    output_type=_LISTUNAVAILABILITYWINDOWSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenGroundStationStream',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.OpenGroundStationStream',
    index=5,
    containing_service=None,
    input_type=_GROUNDSTATIONSTREAMREQUEST,
    output_type=_GROUNDSTATIONSTREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCurrentPlan',
    full_name='stellarstation.api.v1.groundstation.GroundStationService.GetCurrentPlan',
    index=6,
    containing_service=None,
    input_type=_GETCURRENTPLANREQUEST,
    output_type=_GETCURRENTPLANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUNDSTATIONSERVICE)

DESCRIPTOR.services_by_name['GroundStationService'] = _GROUNDSTATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/orbit/orbit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/orbit/orbit.proto',
  package='stellarstation.api.v1.orbit',
  syntax='proto3',
  serialized_options=b'\n\037com.stellarstation.api.v1.orbitB\nOrbitProtoP\001Z8github.com/infostellarinc/go-stellarstation/api/v1/orbit',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'stellarstation/api/v1/orbit/orbit.proto\x12\x1bstellarstation.api.v1.orbit\"%\n\x03Tle\x12\x0e\n\x06line_1\x18\x01 \x01(\t\x12\x0e\n\x06line_2\x18\x02 \x01(\tBi\n\x1f\x63om.stellarstation.api.v1.orbitB\nOrbitProtoP\x01Z8github.com/infostellarinc/go-stellarstation/api/v1/orbitb\x06proto3'
)




_TLE = _descriptor.Descriptor(
  name='Tle',
  full_name='stellarstation.api.v1.orbit.Tle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_1', full_name='stellarstation.api.v1.orbit.Tle.line_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_2', full_name='stellarstation.api.v1.orbit.Tle.line_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=109,
)

DESCRIPTOR.message_types_by_name['Tle'] = _TLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tle = _reflection.GeneratedProtocolMessageType('Tle', (_message.Message,), {
  'DESCRIPTOR' : _TLE,
  '__module__' : 'stellarstation.api.v1.orbit.orbit_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.orbit.Tle)
  })
_sym_db.RegisterMessage(Tle)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from stellarstation.api.v1 import stellarstation_pb2 as stellarstation_dot_api_dot_v1_dot_stellarstation__pb2


class StellarStationServiceStub(object):
    """The public API service of StellarStation, a system supporting communication between satellites
    and ground stations. This API is for use by an operator of a satellite - it is invalid to specify
    satellites that the operator does not own or plans they have not reserved.
    Only using IDs shown on the StellarStation Console or returned in API responses will ensure all
    inputs are valid.

    A pass is a time range where an ground station and satellite can communicate with each other, i.e.,
    the period between Acquisition of Signal (AOS) and Loss of Signal (LOS) of the ground station and
    satellite pair.

    A plan is a scheduled pass that will be executed to send and receive data between the ground
    station and satellite during the time range.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPlans = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/ListPlans',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansResponse.FromString,
                )
        self.CancelPlan = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/CancelPlan',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanResponse.FromString,
                )
        self.ListUpcomingAvailablePasses = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/ListUpcomingAvailablePasses',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesResponse.FromString,
                )
        self.OpenSatelliteStream = channel.stream_stream(
                '/stellarstation.api.v1.StellarStationService/OpenSatelliteStream',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamResponse.FromString,
                )
        self.ReservePass = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/ReservePass',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassResponse.FromString,
                )
        self.AddTle = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/AddTle',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleResponse.FromString,
                )
        self.GetTle = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/GetTle',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleResponse.FromString,
                )
        self.SetTleSource = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/SetTleSource',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetTleSourceRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetTleSourceResponse.FromString,
                )
        self.SetPlanMetadata = channel.unary_unary(
                '/stellarstation.api.v1.StellarStationService/SetPlanMetadata',
                request_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetPlanMetadataRequest.SerializeToString,
                response_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetPlanMetadataResponse.FromString,
                )


class StellarStationServiceServicer(object):
    """The public API service of StellarStation, a system supporting communication between satellites
    and ground stations. This API is for use by an operator of a satellite - it is invalid to specify
    satellites that the operator does not own or plans they have not reserved.
    Only using IDs shown on the StellarStation Console or returned in API responses will ensure all
    inputs are valid.

    A pass is a time range where an ground station and satellite can communicate with each other, i.e.,
    the period between Acquisition of Signal (AOS) and Loss of Signal (LOS) of the ground station and
    satellite pair.

    A plan is a scheduled pass that will be executed to send and receive data between the ground
    station and satellite during the time range.
    """

    def ListPlans(self, request, context):
        """Lists the plans for a particular satellite.

        The request will be closed with an `INVALID_ARGUMENT` status if `satellite_id`,
        `aos_after`, or `aos_before` are missing, or the duration between the two times is longer than
        31 days.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelPlan(self, request, context):
        """Cancel a previously reserved upcoming plan. Cancelling the plan will cause it to not be
        executed. This action cannot be undone, but it is still possible to reserve the corresponding
        pass again by calling `ListUpcomingAvailablePasses` and `ReservePass` as usual - this will
        cause a new plan to be reserved. The plan cannot be cancelled less than ten minutes before
        AOS.

        Canceling a plan may incur a charge based on the time left to AOS. See our cancellation policy
        for details.

        If the plan is not found, the request will return a `NOT_FOUND` error.

        If the plan has already been canceled or is less than ten minutes away from its AOS, the
        request will return a `FAILED_PRECONDITION` error.

        If the plan is ongoing or has already finished executing, the request will return a
        `OUT_OF_RANGE` error.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUpcomingAvailablePasses(self, request, context):
        """Lists upcoming passes for a satellite. Passes that can be scheduled for the satellite with an
        Acquisition of Signal (AOS) within 14 days from now will be returned. This method does not
        reserve passes in any way - it is possible for a pass that is returned by this method to be
        unschedulable when actually trying to schedule because a conflict appeared during that time.

        If the satellite is not found or the client is not authorized for it, the request will return
        a `NOT_FOUND` error.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenSatelliteStream(self, request_iterator, context):
        """Open a stream to a satellite. The returned stream is bi-directional - it can be used by the
        client to send commands to the satellite and data received from the satellite will be returned
        as it is made available. All telemetry received from the satellite on reserved passes along
        with associated events from this point on will be returned as soon as this method is called. If
        `SatelliteStreamRequest.stream_id` is specified, any messages that have been buffered for the
        stream will be returned as well. If `SatelliteStreamRequest.plan_id` is provided, only messages
        for the specified plan will be returned.

        The first `SatelliteStreamRequest` sent on the stream is used for configuring the stream.
        Unless otherwise specified, all configuration is taken from the first request and configuration
        values in subsequent requests will be ignored.

        The stream can be left open for any amount of time and telemetry will be received as available
        and returned. When the client is done with the stream, it should close it successfully. If the
        stream is cancelled with an unexpected error at any point, telemetry received before the next
        call to `OpenSatelliteStream` to resume the stream will be buffered up to 1 minute, and if no
        call to `OpenSatelliteStream` is made with `stream_id` specified to resume the stream, it will
        expire in 10 minutes and a call to `OpenSatelliteStream` with that `stream_id` will be closed
        with a `ABORTED` error.

        If the satellite is not found or the client is not authorized for it, the stream will be closed
        with a `NOT_FOUND` error.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReservePass(self, request, context):
        """Reserves a pass for later execution as a plan. The pass must be specified by a
        `reservation_token` returned in another method like `ListUpcomingAvailablePasses` and its
        `aos_time` must be at least one hour in the future.

        If the `reservation_token` is invalid, the request will return an `INVALID_ARGUMENT` error.

        If the requested pass cannot be scheduled due to a conflict with existing plans or other
        scheduling constraints, the request will return a `FAILED_PRECONDITION` error. This includes
        if the pass `aos_time` is less than one hour in the future.

        Note that the reservation_token may have become unreservable since it was fetched. If that's
        the case, the call to `ReservePass` will fail with a 'FAILED_PRECONDITION' error and
        `ListUpcomingAvailablePasses` should be called again to get a fresh list of reservable passes.
        The pass must be scheduled at least one hour in advance of `aos_time` or it will be rejected.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTle(self, request, context):
        """Adds TLE for a satellite.

        The TLE will be used for satellite orbit calculation until it is superseded by a newly
        added TLE. Adding TLE using this API will automatically change the satellite's TLE source to
        `MANUAL` if it was previously set to `NORAD` to allow for immediate use.

        An 'INVALID_ARGUMENT' error will be returned in the following conditions:
        - the TLE cannot be parsed
        - the TLE norad ID does not correspond to the requested satellite.

        If the satellite is not found or the client is not authorized for it, the request will return
        a `NOT_FOUND` error.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTle(self, request, context):
        """Gets the TLE for a satellite.

        The returned TLE will be the one that has most recently been added to StellarStation and matches
        the satellite's TLE source. This TLE is used when calculating satellite orbits.

        If the satellite is not found or the client is not authorized for it, the request will return
        a `NOT_FOUND` error.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTleSource(self, request, context):
        """Sets the TLE source for a satellite.

        The selected source will be used for all upcoming pass calculations for the satellite. If TLE
        does not exist for a specific source, no passes will be generated.

        An 'INVALID_ARGUMENT' error will be returned in the following condition:
        - no satellite_id is provided.
        - the source provided is invalid.

        If the satellite is not found or the client is not authorized for it, the request will return
        a `NOT_FOUND` error.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPlanMetadata(self, request, context):
        """Sets the metadata for a plan.

        Metadata added to a plan is available via ListPlans RPCs for both satellite and ground station
        APIs. Because of this, it is important not to store sensitive information that the plan's
        satellite operator and ground station operator should not have access to.

        Any metadata set with this method will overwrite existing metadata.

        Status: ALPHA This API is under development and may not work correctly or be changed in backwards
        incompatible ways in the future.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StellarStationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPlans': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPlans,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansResponse.SerializeToString,
            ),
            'CancelPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelPlan,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanResponse.SerializeToString,
            ),
            'ListUpcomingAvailablePasses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUpcomingAvailablePasses,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesResponse.SerializeToString,
            ),
            'OpenSatelliteStream': grpc.stream_stream_rpc_method_handler(
                    servicer.OpenSatelliteStream,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamResponse.SerializeToString,
            ),
            'ReservePass': grpc.unary_unary_rpc_method_handler(
                    servicer.ReservePass,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassResponse.SerializeToString,
            ),
            'AddTle': grpc.unary_unary_rpc_method_handler(
                    servicer.AddTle,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleResponse.SerializeToString,
            ),
            'GetTle': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTle,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleResponse.SerializeToString,
            ),
            'SetTleSource': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTleSource,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetTleSourceRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetTleSourceResponse.SerializeToString,
            ),
            'SetPlanMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPlanMetadata,
                    request_deserializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetPlanMetadataRequest.FromString,
                    response_serializer=stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetPlanMetadataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'stellarstation.api.v1.StellarStationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StellarStationService(object):
    """The public API service of StellarStation, a system supporting communication between satellites
    and ground stations. This API is for use by an operator of a satellite - it is invalid to specify
    satellites that the operator does not own or plans they have not reserved.
    Only using IDs shown on the StellarStation Console or returned in API responses will ensure all
    inputs are valid.

    A pass is a time range where an ground station and satellite can communicate with each other, i.e.,
    the period between Acquisition of Signal (AOS) and Loss of Signal (LOS) of the ground station and
    satellite pair.

    A plan is a scheduled pass that will be executed to send and receive data between the ground
    station and satellite during the time range.
    """

    @staticmethod
    def ListPlans(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/ListPlans',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListPlansResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/CancelPlan',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.CancelPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUpcomingAvailablePasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/ListUpcomingAvailablePasses',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ListUpcomingAvailablePassesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OpenSatelliteStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/stellarstation.api.v1.StellarStationService/OpenSatelliteStream',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SatelliteStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReservePass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/ReservePass',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.ReservePassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddTle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/AddTle',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.AddTleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/GetTle',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.GetTleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTleSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/SetTleSource',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetTleSourceRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetTleSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPlanMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/stellarstation.api.v1.StellarStationService/SetPlanMetadata',
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetPlanMetadataRequest.SerializeToString,
            stellarstation_dot_api_dot_v1_dot_stellarstation__pb2.SetPlanMetadataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
